DydxAdapterConfigBuilder

Struct DydxAdapterConfigBuilder 

pub struct DydxAdapterConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> DydxAdapterConfigBuilder<S>

pub fn build(self) -> DydxAdapterConfig
where S: IsComplete,

Finish building and return the requested object

pub fn network( self, value: DydxNetwork, ) -> DydxAdapterConfigBuilder<SetNetwork<S>>
where S::Network: IsUnset,

Optional (Some / Option setters). Default: <DydxNetwork as Default>::default().

Network environment (mainnet or testnet).

pub fn maybe_network( self, value: Option<DydxNetwork>, ) -> DydxAdapterConfigBuilder<SetNetwork<S>>
where S::Network: IsUnset,

Optional (Some / Option setters). Default: <DydxNetwork as Default>::default().

Network environment (mainnet or testnet).

pub fn base_url(self, value: String) -> DydxAdapterConfigBuilder<SetBaseUrl<S>>
where S::BaseUrl: IsUnset,

Optional (Some / Option setters). Default: urls::http_base_url(DydxNetwork::Mainnet).to_string().

Base URL for the HTTP API.

pub fn maybe_base_url( self, value: Option<String>, ) -> DydxAdapterConfigBuilder<SetBaseUrl<S>>
where S::BaseUrl: IsUnset,

Optional (Some / Option setters). Default: urls::http_base_url(DydxNetwork::Mainnet).to_string().

Base URL for the HTTP API.

pub fn ws_url(self, value: String) -> DydxAdapterConfigBuilder<SetWsUrl<S>>
where S::WsUrl: IsUnset,

Optional (Some / Option setters). Default: urls::ws_url(DydxNetwork::Mainnet).to_string().

Base URL for the WebSocket API.

pub fn maybe_ws_url( self, value: Option<String>, ) -> DydxAdapterConfigBuilder<SetWsUrl<S>>
where S::WsUrl: IsUnset,

Optional (Some / Option setters). Default: urls::ws_url(DydxNetwork::Mainnet).to_string().

Base URL for the WebSocket API.

pub fn grpc_url(self, value: String) -> DydxAdapterConfigBuilder<SetGrpcUrl<S>>
where S::GrpcUrl: IsUnset,

Optional (Some / Option setters). Default: urls::grpc_urls(DydxNetwork::Mainnet)[0].to_string().

Base URL for the gRPC API (Cosmos SDK transactions).

For backwards compatibility, a single URL can be provided. Consider using grpc_urls for fallback support.

pub fn maybe_grpc_url( self, value: Option<String>, ) -> DydxAdapterConfigBuilder<SetGrpcUrl<S>>
where S::GrpcUrl: IsUnset,

Optional (Some / Option setters). Default: urls::grpc_urls(DydxNetwork::Mainnet)[0].to_string().

Base URL for the gRPC API (Cosmos SDK transactions).

For backwards compatibility, a single URL can be provided. Consider using grpc_urls for fallback support.

pub fn grpc_urls( self, value: Vec<String>, ) -> DydxAdapterConfigBuilder<SetGrpcUrls<S>>
where S::GrpcUrls: IsUnset,

Optional (Some / Option setters). Default:

urls::grpc_urls(DydxNetwork::Mainnet)
    .iter()
    .map(|&s| s.to_string())
    .collect()

List of gRPC URLs with fallback support.

If provided, the client will attempt to connect to each URL in order until a successful connection is established. This is recommended for production use in DEX environments where nodes can fail.

pub fn maybe_grpc_urls( self, value: Option<Vec<String>>, ) -> DydxAdapterConfigBuilder<SetGrpcUrls<S>>
where S::GrpcUrls: IsUnset,

Optional (Some / Option setters). Default:

urls::grpc_urls(DydxNetwork::Mainnet)
    .iter()
    .map(|&s| s.to_string())
    .collect()

List of gRPC URLs with fallback support.

If provided, the client will attempt to connect to each URL in order until a successful connection is established. This is recommended for production use in DEX environments where nodes can fail.

pub fn chain_id(self, value: String) -> DydxAdapterConfigBuilder<SetChainId<S>>
where S::ChainId: IsUnset,

Optional (Some / Option setters). Default: DYDX_CHAIN_ID.to_string().

Chain ID (e.g., “dydx-mainnet-1” for mainnet, “dydx-testnet-4” for testnet).

pub fn maybe_chain_id( self, value: Option<String>, ) -> DydxAdapterConfigBuilder<SetChainId<S>>
where S::ChainId: IsUnset,

Optional (Some / Option setters). Default: DYDX_CHAIN_ID.to_string().

Chain ID (e.g., “dydx-mainnet-1” for mainnet, “dydx-testnet-4” for testnet).

pub fn timeout_secs( self, value: u64, ) -> DydxAdapterConfigBuilder<SetTimeoutSecs<S>>
where S::TimeoutSecs: IsUnset,

Optional (Some / Option setters). Default: 30.

Request timeout in seconds.

pub fn maybe_timeout_secs( self, value: Option<u64>, ) -> DydxAdapterConfigBuilder<SetTimeoutSecs<S>>
where S::TimeoutSecs: IsUnset,

Optional (Some / Option setters). Default: 30.

Request timeout in seconds.

pub fn wallet_address( self, value: String, ) -> DydxAdapterConfigBuilder<SetWalletAddress<S>>
where S::WalletAddress: IsUnset,

Optional (Some / Option setters). Wallet address for the account.

If not provided, falls back to environment variable:

  • Mainnet: DYDX_WALLET_ADDRESS
  • Testnet: DYDX_TESTNET_WALLET_ADDRESS

Use resolve_wallet_address() to resolve from config or environment.

pub fn maybe_wallet_address( self, value: Option<String>, ) -> DydxAdapterConfigBuilder<SetWalletAddress<S>>
where S::WalletAddress: IsUnset,

Optional (Some / Option setters). Wallet address for the account.

If not provided, falls back to environment variable:

  • Mainnet: DYDX_WALLET_ADDRESS
  • Testnet: DYDX_TESTNET_WALLET_ADDRESS

Use resolve_wallet_address() to resolve from config or environment.

pub fn subaccount( self, value: u32, ) -> DydxAdapterConfigBuilder<SetSubaccount<S>>
where S::Subaccount: IsUnset,

Optional (Some / Option setters). Default: 0.

Subaccount number (default: 0).

pub fn maybe_subaccount( self, value: Option<u32>, ) -> DydxAdapterConfigBuilder<SetSubaccount<S>>
where S::Subaccount: IsUnset,

Optional (Some / Option setters). Default: 0.

Subaccount number (default: 0).

pub fn private_key( self, value: String, ) -> DydxAdapterConfigBuilder<SetPrivateKey<S>>
where S::PrivateKey: IsUnset,

Optional (Some / Option setters). Private key (hex) for wallet signing.

If not provided, falls back to environment variable:

  • Mainnet: DYDX_PRIVATE_KEY
  • Testnet: DYDX_TESTNET_PRIVATE_KEY

Use DydxCredential::resolve() to resolve from config or environment.

pub fn maybe_private_key( self, value: Option<String>, ) -> DydxAdapterConfigBuilder<SetPrivateKey<S>>
where S::PrivateKey: IsUnset,

Optional (Some / Option setters). Private key (hex) for wallet signing.

If not provided, falls back to environment variable:

  • Mainnet: DYDX_PRIVATE_KEY
  • Testnet: DYDX_TESTNET_PRIVATE_KEY

Use DydxCredential::resolve() to resolve from config or environment.

pub fn authenticator_ids( self, value: Vec<u64>, ) -> DydxAdapterConfigBuilder<SetAuthenticatorIds<S>>
where S::AuthenticatorIds: IsUnset,

Optional (Some / Option setters). Default: <Vec<u64> as Default>::default().

Authenticator IDs for permissioned key trading.

When provided, transactions will include a TxExtension to enable trading via sub-accounts using delegated signing keys. This is an advanced feature for institutional setups with separated hot/cold wallet architectures.

See https://docs.dydx.xyz/concepts/trading/authenticators for details on permissioned keys and authenticator configuration.

pub fn maybe_authenticator_ids( self, value: Option<Vec<u64>>, ) -> DydxAdapterConfigBuilder<SetAuthenticatorIds<S>>
where S::AuthenticatorIds: IsUnset,

Optional (Some / Option setters). Default: <Vec<u64> as Default>::default().

Authenticator IDs for permissioned key trading.

When provided, transactions will include a TxExtension to enable trading via sub-accounts using delegated signing keys. This is an advanced feature for institutional setups with separated hot/cold wallet architectures.

See https://docs.dydx.xyz/concepts/trading/authenticators for details on permissioned keys and authenticator configuration.

pub fn max_retries( self, value: u32, ) -> DydxAdapterConfigBuilder<SetMaxRetries<S>>
where S::MaxRetries: IsUnset,

Optional (Some / Option setters). Default: 3.

Maximum number of retries for failed requests (default: 3).

pub fn maybe_max_retries( self, value: Option<u32>, ) -> DydxAdapterConfigBuilder<SetMaxRetries<S>>
where S::MaxRetries: IsUnset,

Optional (Some / Option setters). Default: 3.

Maximum number of retries for failed requests (default: 3).

pub fn retry_delay_initial_ms( self, value: u64, ) -> DydxAdapterConfigBuilder<SetRetryDelayInitialMs<S>>
where S::RetryDelayInitialMs: IsUnset,

Optional (Some / Option setters). Default: 1000.

Initial retry delay in milliseconds (default: 1000ms).

pub fn maybe_retry_delay_initial_ms( self, value: Option<u64>, ) -> DydxAdapterConfigBuilder<SetRetryDelayInitialMs<S>>
where S::RetryDelayInitialMs: IsUnset,

Optional (Some / Option setters). Default: 1000.

Initial retry delay in milliseconds (default: 1000ms).

pub fn retry_delay_max_ms( self, value: u64, ) -> DydxAdapterConfigBuilder<SetRetryDelayMaxMs<S>>
where S::RetryDelayMaxMs: IsUnset,

Optional (Some / Option setters). Default: 10000.

Maximum retry delay in milliseconds (default: 10000ms).

pub fn maybe_retry_delay_max_ms( self, value: Option<u64>, ) -> DydxAdapterConfigBuilder<SetRetryDelayMaxMs<S>>
where S::RetryDelayMaxMs: IsUnset,

Optional (Some / Option setters). Default: 10000.

Maximum retry delay in milliseconds (default: 10000ms).

pub fn grpc_rate_limit_per_second( self, value: u32, ) -> DydxAdapterConfigBuilder<SetGrpcRateLimitPerSecond<S>>
where S::GrpcRateLimitPerSecond: IsUnset,

Optional (Some / Option setters). gRPC rate limit: maximum broadcast requests per second.

Controls the rate of gRPC broadcast_tx calls to prevent 429 (ResourceExhausted) errors from validator nodes. Known provider limits:

  • Polkachu: 300 req/min (~5 req/s)
  • KingNodes: 250 req/min (~4.2 req/s)
  • AutoStake: 4 req/s

Default: 4 requests per second (conservative, works across all public providers). When None, rate limiting is disabled.

pub fn maybe_grpc_rate_limit_per_second( self, value: Option<u32>, ) -> DydxAdapterConfigBuilder<SetGrpcRateLimitPerSecond<S>>
where S::GrpcRateLimitPerSecond: IsUnset,

Optional (Some / Option setters). gRPC rate limit: maximum broadcast requests per second.

Controls the rate of gRPC broadcast_tx calls to prevent 429 (ResourceExhausted) errors from validator nodes. Known provider limits:

  • Polkachu: 300 req/min (~5 req/s)
  • KingNodes: 250 req/min (~4.2 req/s)
  • AutoStake: 4 req/s

Default: 4 requests per second (conservative, works across all public providers). When None, rate limiting is disabled.

pub fn proxy_url( self, value: String, ) -> DydxAdapterConfigBuilder<SetProxyUrl<S>>
where S::ProxyUrl: IsUnset,

Optional (Some / Option setters). Optional proxy URL for HTTP and WebSocket transports.

pub fn maybe_proxy_url( self, value: Option<String>, ) -> DydxAdapterConfigBuilder<SetProxyUrl<S>>
where S::ProxyUrl: IsUnset,

Optional (Some / Option setters). Optional proxy URL for HTTP and WebSocket transports.

pub fn transport_backend( self, value: TransportBackend, ) -> DydxAdapterConfigBuilder<SetTransportBackend<S>>
where S::TransportBackend: IsUnset,

Optional (Some / Option setters). Default: <TransportBackend as Default>::default().

WebSocket transport backend (defaults to Tungstenite).

pub fn maybe_transport_backend( self, value: Option<TransportBackend>, ) -> DydxAdapterConfigBuilder<SetTransportBackend<S>>
where S::TransportBackend: IsUnset,

Optional (Some / Option setters). Default: <TransportBackend as Default>::default().

WebSocket transport backend (defaults to Tungstenite).